@@ -23,7 +23,12 @@ add_nflscrapr_mutations <- function(pbp) {
                               (.data$play_description == "END GAME" & is.na(.data$time)), "00:00", .data$time),
       time = dplyr::if_else(.data$play_description == 'GAME', "15:00", .data$time),
       # Create a column with the time in seconds remaining for the quarter:
-      quarter_seconds_remaining = time_to_seconds(.data$time)
+      quarter_seconds_remaining = time_to_seconds(.data$time),
+      play_description = dplyr::case_when(
+        stringr::str_detect(.data$play_description, "(?<=kicks )[:alpha:]{1,}.[:alpha:]{1,}(?= yards)") ~
+          stringr::str_replace(.data$play_description, "(?<=kicks )[:alpha:]{1,}.[:alpha:]{1,}(?= yards)", as.character(.data$kick_distance)),
+        TRUE ~ .data$play_description
+      )
     ) %>%
     #put plays in the right order
     dplyr::group_by(.data$game_id) %>%
@@ -87,6 +92,12 @@ add_nflscrapr_mutations <- function(pbp) {
           stringr::str_remove("\\([0-9]{2}+ Yards\\)") %>%
           stringr::str_squish(), NA_character_
       ),
+      # The new "dynamic Kickoff" in the 2024 season introduces a new penalty type
+      penalty_type = dplyr::if_else(
+        .data$penalty == 1 & stringr::str_detect(tolower(.data$play_description), "kickoff short of landing zone"),
+        "Kickoff Short of Landing Zone",
+        .data$penalty_type
+      ),
       # Make plays marked with down == 0 as NA:
       down = dplyr::if_else(
         .data$down == 0,
@@ -141,7 +152,7 @@ add_nflscrapr_mutations <- function(pbp) {
       lead_ko = case_when(
         dplyr::lead(.data$kickoff_attempt) == 1 &
           .data$game_id == dplyr::lead(.data$game_id) &
-          !stringr::str_detect(tolower(.data$play_description), "(injured sf )|(tonight's attendance )|(injury update )|(end quarter)|(timeout)|( captains:)|( captains )|( captians:)|( humidity:)|(note - )|( deferred)|(game start )") &
+          !stringr::str_detect(tolower(.data$play_description), "(injured sf )|(tonight's attendance )|(injury update )|(end quarter)|(timeout)|( captains:)|( captains )|( captians:)|( humidity:)|(note - )|( deferred)|(game start )|( game has been suspended)") &
           !stringr::str_detect(.data$play_description, "GAME ") &
           !.data$play_description %in% c("GAME", "Two-Minute Warning", "The game has resumed.") &
           is.na(.data$two_point_conv_result) &
@@ -196,7 +207,7 @@ add_nflscrapr_mutations <- function(pbp) {
         .data$away_team, .data$home_team
       ),
 
-      yardline = dplyr::if_else(.data$yardline == "50", "MID 50", .data$yardline),
+      yardline = dplyr::if_else(stringr::str_detect(.data$yardline, "50"), "MID 50", .data$yardline),
       yardline = dplyr::if_else(
         nchar(.data$yardline) == 0 | is.null(.data$yardline) | .data$yardline == "NULL" | is.na(.data$yardline),
         dplyr::lead(.data$yardline), .data$yardline
@@ -392,12 +403,6 @@ add_nflscrapr_mutations <- function(pbp) {
         .data$replay_or_challenge == 1 & .data$timeout == 1 & is.na(.data$timeout_team), .data$tmp_timeout, .data$timeout_team
 
       ),
-      timeout_team = dplyr::if_else(
-        .data$season <= 2015 & (.data$home_team %in% c("JAC", "JAX") | .data$away_team %in% c("JAC", "JAX")) & .data$timeout_team == "JAX",
-        "JAC",
-        .data$timeout_team
-      ),
-
 
       home_timeouts_remaining = dplyr::if_else(
         .data$quarter %in% c(1, 2, 3, 4),
@@ -426,6 +431,23 @@ add_nflscrapr_mutations <- function(pbp) {
         0, .data$away_timeout_used
       )
     ) %>%
+    # replace empty strings in yard line variables
+    dplyr::mutate_at(
+      .vars = c("yardline", "drive_start_yard_line" ,"drive_end_yard_line"),
+      .funs = ~ dplyr::na_if(.x, "")
+    ) %>%
+    # fix cases where a yardline variable misses the blank space between team name
+    # and yard number. At the point of adding this, the only spot where this happened
+    # was in the variable drive_start_yard_line in the games
+    # "2000_01_CAR_WAS", "2000_02_NE_NYJ", and "2000_03_ATL_CAR"
+    dplyr::mutate_at(
+      .vars = c("yardline", "drive_start_yard_line" ,"drive_end_yard_line"),
+      .funs = ~ dplyr::case_when(
+        stringr::str_detect(.x, "[:upper:]{2,3}(?=[:digit:]{1,2})") ~
+          stringr::str_c(stringr::str_extract(.x, "[:upper:]{2,3}"), stringr::str_extract(.x, "[:digit:]{1,2}"), sep = " "),
+        TRUE ~ .x
+      )
+    ) %>%
     # Group by the game_half to then create cumulative timeouts used for both
     # the home and away teams:
     dplyr::group_by(.data$game_id, .data$game_half) %>%
@@ -644,8 +666,8 @@ make_model_mutations <- function(pbp) {
 
 
 fix_scrambles <- function(pbp) {
-  # skip below code if 2005 is not in the data
-  if (!2005 %in% pbp$season) return(pbp)
+  # skip below code if <= 2005 is not in the data
+  if (min(pbp$season) > 2005) return(pbp)
 
   pbp %>%
     dplyr::mutate(
@@ -655,12 +677,9 @@ fix_scrambles <- function(pbp) {
     dplyr::select(-"scramble_id")
 
   # Some notes on the scramble_fix:
-  # This marks scrambles in the 2005 season using charting data
+  # This marks scrambles in the 1999 - 2005 season using charting data
   # Because NFL did not put scramble in play description during this season
-  # Data from Football Outsiders (thanks to Aaron Schatz!)
-  # 2005 season, Weeks 1-16 are based on charting
-  # 2005 season, Weeks 17-21 are guesses (basically every QB run except those that were a) a loss, b) no gain, or c) on 3/4 down with 1-2 to go).
-  # Plays nullified by penalty are not included.
+  # Data from Aaron Schatz!
 }
 
 translate_play_type_nfl <- function(play_type_nfl){
